@@ -11,16 +11,11 @@ use strict;
 use warnings;
 
 package Sub::Chain::Group;
-{
-  $Sub::Chain::Group::VERSION = '0.013';
-}
-# git description: v0.012-8-ge16d2b1
+# git description: v0.013-4-g6f84b56
 
-BEGIN {
-  $Sub::Chain::Group::AUTHORITY = 'cpan:RWSTAUNER';
-}
+our $AUTHORITY = 'cpan:RWSTAUNER';
 # ABSTRACT: Group chains of subs by field name
-
+$Sub::Chain::Group::VERSION = '0.014';
 use Carp qw(croak carp);
 
 # this seems a little dirty, but it's not appropriate to put it in Sub::Chain
@@ -303,7 +298,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =for :stopwords Randy Stauner ACKNOWLEDGEMENTS TODO cpan testmatrix url annocpan anno
 bugtracker rt cpants kwalitee diff irc mailto metadata placeholders
@@ -315,7 +310,7 @@ Sub::Chain::Group - Group chains of subs by field name
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =head1 SYNOPSIS
 
@@ -705,58 +700,18 @@ in addition to those websites please use your favorite search engine to discover
 
 =item *
 
-Search CPAN
+MetaCPAN
 
-The default CPAN search engine, useful to view POD in HTML format.
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://search.cpan.org/dist/Sub-Chain-Group>
-
-=item *
-
-RT: CPAN's Bug Tracker
-
-The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Sub-Chain-Group>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/Sub-Chain-Group>
-
-=item *
-
-CPAN Testers
-
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
-
-L<http://www.cpantesters.org/distro/S/Sub-Chain-Group>
-
-=item *
-
-CPAN Testers Matrix
-
-The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
-
-L<http://matrix.cpantesters.org/?dist=Sub-Chain-Group>
-
-=item *
-
-CPAN Testers Dependencies
-
-The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
-
-L<http://deps.cpantesters.org/?module=Sub::Chain::Group>
+L<http://metacpan.org/release/Sub-Chain-Group>
 
 =back
 
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests by email to C<bug-sub-chain-group at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Sub-Chain-Group>. You will be automatically notified of any
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Sub-Chain-Group>. You will be automatically notified of any
 progress on the request by the system.
 
 =head2 Source Code
